@@ -339,7 +339,7 @@ class PaLM(nn.Module):
         finetune_scopes = tuple(),
         cross_entropy_ignore_index = 0,
         cross_attend = False,
-        start_token_id = None
+        default_start_token_id = None
     ):
         super().__init__()
         self.dim = dim
@@ -348,7 +348,7 @@ class PaLM(nn.Module):
         self.causal = causal
 
         self.num_tokens = num_tokens
-        self.start_token_id = start_token_id
+        self.default_start_token_id = default_start_token_id
 
         self.cross_attend = cross_attend
 
@@ -492,8 +492,14 @@ class PaLM(nn.Module):
         use_tqdm = False,
         **kwargs
     ):
+        assert self.causal
+
         if not exists(prompt):
-            prompt = torch.randint(0, self.num_tokens, (1, 1))
+            if exists(self.default_start_token_id):
+                prompt = torch.full((1, 1), self.default_start_token_id)
+            else:
+                prompt = torch.randint(0, self.num_tokens, (1, 1))
+
             prompt = prompt.to(self.device)
             return_seq_without_prompt = False
 
